@@ -40,43 +40,128 @@ Window last_focused;
 int screen;
 KeySym key;
 
+/*
+ * The slide positions are derived from FVMW sources, file fvmm/move_resize.c,
+ * to there added by Greg J. Badros, gjb@cs.washington.edu
+ */
+
+static float posCFV[] = {.005,.01,.02,.03,.08,.18,.3,.45,.65,.80,.88,.93,.95,.97,.99,1.0};
+
 void pull (struct tilda_window_ *tw)
 {
+#ifdef DEBUG
+    puts("pull");
+#endif
+
+    gint i;
     gint w, h;
     static gint pos=0;
 
+    static gint last_pos_y = -1;
+    static gint last_height = -1;
+
+    static gint pos_V_in = 0;
+    static gint posIV[2][16];
+
+    if (cfg_getint (tw->tc, "y_pos") != last_pos_y)
+    {
+        last_pos_y = cfg_getint (tw->tc, "y_pos");
+        pos_V_in = 0;
+    }
+
+    if (cfg_getint (tw->tc, "max_height") != last_height)
+    {
+        last_height = cfg_getint (tw->tc, "max_height");
+        pos_V_in = 0;
+    }
+
+    if (!pos_V_in)
+    {
+        for (i=0; i<16; i++)
+        {
+            posIV[1][i] = (gint)(posCFV[i]*last_height);
+            posIV[0][i] = last_pos_y;
+        }
+
+        pos_V_in = 1;
+    }
+    
     if (pos == 0)
     {
         gdk_threads_enter();
-        
+
         pos++;
-        
+
         if (gtk_window_is_active ((GtkWindow *) tw->window) == FALSE)
             gtk_window_present ((GtkWindow *) tw->window);
         else
             gtk_widget_show ((GtkWidget *) tw->window);
-            
-        if ((strcasecmp (tw->tc->s_pinned, "true")) == 0)
+
+        if (cfg_getbool (tw->tc, "pinned"))
             gtk_window_stick (GTK_WINDOW (tw->window));
 
-        if ((strcasecmp (tw->tc->s_above, "true")) == 0)
+        if (cfg_getbool (tw->tc, "above"))
             gtk_window_set_keep_above (GTK_WINDOW (tw->window), TRUE);
 
-        gtk_window_move ((GtkWindow *) tw->window, tw->tc->x_pos, tw->tc->y_pos);
-        gtk_window_resize ((GtkWindow *) tw->window, tw->tc->max_width, tw->tc->max_height);
-        
+        if (cfg_getbool (tw->tc, ("animation")))
+        {
+            gdk_threads_leave();
+
+            for (i=0; i<16; i++)
+            {
+                gdk_threads_enter();
+                gtk_window_move ((GtkWindow *) tw->window, cfg_getint (tw->tc, "x_pos"), posIV[0][i]);
+                gtk_window_resize ((GtkWindow *) tw->window, cfg_getint (tw->tc, "max_width"), posIV[1][i]);
+
+                gdk_flush();
+                gdk_threads_leave();
+                usleep (cfg_getint (tw->tc, "slide_sleep_usec"));
+            }
+        }
+        else
+        {
+            gtk_window_move ((GtkWindow *) tw->window, cfg_getint (tw->tc, "x_pos"), cfg_getint (tw->tc, "y_pos"));
+            gtk_window_resize ((GtkWindow *) tw->window, cfg_getint (tw->tc, "max_width"), cfg_getint (tw->tc, "max_height"));
+            gdk_flush();
+            gdk_threads_leave();
+        }
+
+        gdk_threads_enter();
+
         gdk_window_focus (tw->window->window, gtk_get_current_event_time ());
-        
+
         gdk_flush ();
         gdk_threads_leave();
     }
-    else 
+    else
     {
         gdk_threads_enter();
-        
+
         pos--;
-        
-        gtk_window_resize ((GtkWindow *) tw->window, tw->tc->min_width, tw->tc->min_height);
+
+        if (cfg_getbool (tw->tc, ("animation")))
+        {
+            gdk_threads_leave();
+            for (i=15; i>=0; i--)
+            {
+                gdk_threads_enter();
+                gtk_window_move ((GtkWindow *) tw->window, cfg_getint (tw->tc, "x_pos"), posIV[0][i]);
+                gtk_window_resize ((GtkWindow *) tw->window, cfg_getint (tw->tc, "max_width"), posIV[1][i]);
+
+                gdk_flush();
+                gdk_threads_leave();
+                usleep (cfg_getint (tw->tc, "slide_sleep_usec"));
+            }
+        }
+        else
+        {
+            gtk_window_resize ((GtkWindow *) tw->window, cfg_getint (tw->tc, "min_width"), cfg_getint (tw->tc, "min_height"));
+            gdk_flush();
+            gdk_threads_leave();
+        }
+
+        gdk_threads_enter();
+
         gtk_widget_hide ((GtkWidget *) tw->window);
 
         gdk_flush ();
@@ -86,13 +171,17 @@ void pull (struct tilda_window_ *tw)
 
 void key_grab (tilda_window *tw)
 {
+#ifdef DEBUG
+    puts("key_grab");
+#endif
+
     XModifierKeymap *modmap;
-    gchar tmp_key[25];
+    gchar tmp_key[32];
     unsigned int numlockmask = 0;
     unsigned int modmask = 0;
     gint i, j;
 
-    g_strlcpy (tmp_key, tw->tc->s_key, sizeof (tmp_key));
+    g_strlcpy (tmp_key, cfg_getstr (tw->tc, "key"), sizeof (tmp_key));
 
     /* Key grabbing stuff taken from yeahconsole who took it from evilwm */
     modmap = XGetModifierMapping(dpy);
@@ -121,9 +210,9 @@ void key_grab (tilda_window *tw)
     if (strstr(tmp_key, "None"))
         modmask = 0;
 
-    if (!strstr(tmp_key, "+")) 
+    if (!strstr(tmp_key, "+"))
         perror ("Key Incorrect -- Read the README or tilda.sf.net for info, rerun as 'tilda -C' to set keybinding\n");
-    
+
     if (strtok(tmp_key, "+"))
         key = XStringToKeysym(strtok(NULL, "+"));
 
@@ -150,14 +239,10 @@ void *wait_for_signal (tilda_window *tw)
 
     key_grab (tw);
 
-    if (QUICK_STRCMP (tw->tc->s_down, "TRUE") == 0)
+    if (cfg_getbool (tw->tc, "down"))
         pull (tw);
     else
     {
-        /*gdk_threads_enter();
-        gtk_widget_hide (tw->window);
-        gdk_flush ();
-        gdk_threads_leave();*/
         pull (tw);
         pull (tw);
     }
